"""Removed fake data used for upgrading recommendation system

Revision ID: 697518134a33
Revises: e32bdffdf6d8
Create Date: 2024-10-14 16:28:30.797590

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '697518134a33'
down_revision: Union[str, None] = 'e32bdffdf6d8'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
